/**
 * Common routines for displaying data to the user
 *
 * This file is part of DCC Monitor.
 *
 * Copyright 2007, 2008 Peter Lebbing <peter@digitalbrains.com>
 *
 * DCC Monitor is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * DCC Monitor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DCC Monitor.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdio.h>
#include <stddef.h>
#include <time.h>
#include "global.h"
#include "display.h"

/**
 * Dumps a frame on stdout in hexadecimal format.
 */
void dump_hex_data (struct s_frame *frame) {
  printf ("\tdata:");
  for (size_t i = 0; i < frame->len; i++) {
    printf (" %02x", frame->data[i]);
  }
  putchar ('\n');
}

/**
 * Starts a line on stdout for reporting frame data.
 */
void start_output_line (struct s_frame *frame) {
  char timebuf[255];
  struct tm *loctime;

  // Make the reception time human-readable
  loctime = localtime (&frame->time);
  strftime (timebuf, 255, "%X", loctime); // Preferred locale time-of-day
  
  printf ("%s Address %u", timebuf, frame->addr);
}
